Time Cover Genders
==================

This example uses data from
[CrowdFlower's "Data For Everyone"](http://www.crowdflower.com/data-for-everyone/)
data set on the yearly breakdown of the number of men and women appearing on
Time Magazine covers from the year 1923.
